#
# spec file for package python3-setuptools_scm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-setuptools_scm
Version:        1.11.1
Release:        2.4
Summary:        The blessed package to manage your versions by scm tags
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/pypa/setuptools_scm
Source0:        https://files.pythonhosted.org/packages/source/s/setuptools_scm/setuptools_scm-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# Testing requirements
BuildRequires:  git
BuildRequires:  mercurial
BuildRequires:  python3-pytest
Requires:       python3-setuptools
Recommends:     git
Recommends:     mecurial
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Setuptools_scm handles managing your python package versions in scm metadata instead of declaring them as the version argument or in a scm managed file.

It also handles file finders for the supported scm’s.

%prep
%setup -q -n setuptools_scm-%{version}
# fix python version used in some tests
sed -i "s/python/python3/g" testing/test_regressions.py

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
PYTHONPATH=%{buildroot}%{python3_sitelib} py.test

%files
%defattr(-,root,root,-)
%{python3_sitelib}/*
%doc README.rst CHANGELOG.rst LICENSE

%changelog
* Sat Jun 18 2016 arun@gmx.de
- update to version 1.11.1:
  * fix issue #88 - better docs for sphinx usage (thanks Jason)
  * fix issue #89 - use normpath to deal with windows (thanks Te-jé
    Rodgers for reporting and fixing)
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Fri Apr  8 2016 arun@gmx.de
- specfile:
  * tar.bz2 -> tar.gz
- update to version 1.11.0:
  * always run tag_to_version so in order to handle prefixes on old
    setuptools (thanks to Brian May)
  * drop support for python 3.2
  * extend the error message on missing scm metadata (thanks Markus
    Unterwaditzer)
  * fix bug when using callable version_scheme (thanks Esben
    Haabendal)
* Sun Dec 13 2015 arun@gmx.de
- specfile:
  * moved from tar.gz to tar.bz2 on pypi (at least no tar.gz available)
- update to version 1.10.1:
  * fix issue #73 - in hg pre commit merge, consider parent1 instead
    of failing
- changes from version 1.10.0:
  * add support for overriding the version number via the environment
    variable SETUPTOOLS_SCM_PRETEND_VERSION
  * fix isssue #63 by adding the --match parameter to the git describe
    call and prepare the possibility of passing more options to scm
    backends
  * fix issue #70 and #71 by introducing the parse keyword to specify
    custom scm parsing, its an expert feature, use with caution
  * this change also introduces the setuptools_scm.parse_scm_fallback
    entrypoint which can be used to register custom archive fallbacks
* Sat Nov 14 2015 arun@gmx.de
- specfile:
  * pypi moved to tar.gz (Was tar.bz2)
- update to version 1.9.0:
  * Add relative_to parameter to get_version function; fixes #44 per
    [#45].
* Sat Sep 19 2015 arun@gmx.de
- specfile:
  * pypi changed from tar.gz to tar.bz2
  * some tests call python, but need to call python3. fixed via sed call
- update to version 1.8.0:
  * fix issue with setuptools wrong version warnings being printed to
    standard out. User is informed now by distutils-warnings.
  * restructure root finding, we now reliably ignore outer scm and
    prefer PKG-INFO over scm, fixes #43 and #45
* Sat Aug 15 2015 arun@gmx.de
- update to version 1.7.0:
  * correct the url to github thanks David Szotten
  * enhance scm not found errors with a note on git tarballs thanks Markus
  * add support for write_to_template
* Wed Aug 12 2015 toddrme2178@gmail.com
- Add unit tests
* Sat Aug  1 2015 arun@gmx.de
- specfile:
  * updated url
- update to version 1.6.0:
  * bail out early if the scm is missing
    this brings issues with git tarballs and older devpi-client releases
    to light, before we would let the setup stay at version 0.0, now
    there is a ValueError
  * propperly raise errors on write_to missuse (thanks Te-jé Rodgers)
* Mon Jul 13 2015 arun@gmx.de
- update to version 1.5.5.:
  * Fix bug on Python 2 on Windows when environment has unicode
    fields.
* Sun Jun 14 2015 arun@gmx.de
- update to version 1.5.4:
  * Fix bug on Python 2 when version is loaded from existing metadata.
- changes from version 1.5.3:
  * #28: Fix decoding error when PKG-INFO contains non-ASCII.
* Sun May 31 2015 arun@gmx.de
- update to version 1.5.2:
  * add zip_safe flag
- changes from version 1.5.1:
  * fix file access bug i missed in 1.5
- changes from version 1.5.0:
  * moved setuptools integration related code to own file
  * support storing version strings into a module/text file using the
    write_to coniguration parameter
* Mon May 25 2015 arun@gmx.de
- specfile:
  * changes from - to _ in tar name
- update to version 1.4.1:
  (no changelog available)
- changes from version 1.4.0:
  * propper handling for sdist
  * fix file-finder failure from windows
  * resuffle docs
* Sat Mar 14 2015 arun@gmx.de
- update to version 1.3.0:
  * support setuptools easy_install egg creation details by
    hardwireing the version in the sdist
* Wed Mar  4 2015 arun@gmx.de
- update to version 1.2.0:
  * fail in all install cases on fresh checkout
  * better note
  * print the note when using setup.py in a fresh checkout, fixes #22
  * support working with setuptools pre-12, fixes #20 #21 and #23
* Tue Mar  3 2015 arun@gmx.de
- initial version
